﻿using System;
using System.Collections.Generic;
using System.Drawing;
using System.Drawing.Text;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace PuzzlePlayer_Namespace
{
    internal class PuzzleForm : Form
    {
        private Button solvebutton;
        private Button hintbutton;
        private Button generatebutton;
        private Label boardlabel;
        private TextBox informationbox;
        public Graphics graphics;

        private Board board;
        public Board Board //Updating the Board member will immediately call board.Draw method so that the board is updated visually
        {
            get { return board; }
            set
            {
                board = value;
                board.Draw(graphics, new Point(220, 30), new Size(400, 400));
            }
        }

        public PuzzleForm(Board b = null, Size s = default(Size)) //Takes Board and Size parameter and sets up the PuzzleForm window.
        {
            if (s == default(Size)) s = new Size(800, 500);
            this.Size = s;
            graphics = this.CreateGraphics();
            generatebutton = new Button();
            hintbutton = new Button();
            solvebutton = new Button();
            informationbox = new TextBox();
            Board = b;
            CreateUI();
            UpdateUI();
            this.Resize += (object sender, EventArgs ea) =>
            {
                UpdateUI();
            };

            // example board: https://imgur.com/spyYaPl
            ///*
            int[,] test = Binary.GetClearBoard(Board.boardState.GetLength(0));

            test[0, 0] = 1;
            test[1, 0] = 1;
            test[6, 0] = 1;
            test[3, 1] = 1;
            test[0, 2] = 1;
            test[1, 2] = 1;
            test[3, 2] = 1;
            test[5, 4] = 1;
            test[6, 4] = 1;
            test[1, 5] = 1;
            test[2, 5] = 1;
            test[5, 5] = 1;
            test[1, 7] = 1;
            test[3, 7] = 0;
            test[6, 7] = 1;

            board.boardState = test;
            //Board.setBoardState(test);

            //*/
        }
        private void CreateUI()
        {
            Point boardP = new Point(220, 30);
            Size boardS = new Size(400, 400);

            void CreateButton(Button b)
            {
                Controls.Add(b);
                b.Size = new Size(80, 50);
                b.BackColor = Color.Gainsboro;
                b.Text = "DEFAULT0";
            }
            CreateButton(generatebutton);
            generatebutton.Text = "Generate";
            generatebutton.MouseClick += (object sender, MouseEventArgs mea) => 
            {
                board.Generate();
                board.Draw(graphics, boardP, boardS);
            };
            CreateButton(hintbutton);
            hintbutton.Text = "Hint";
            hintbutton.MouseClick += (object sender, MouseEventArgs mea) =>
            {
                board.Draw(graphics, boardP, boardS);
                MessageBox.Show("Hint: geef op");
            };
            CreateButton(solvebutton);
            solvebutton.Text = "Solve";
            solvebutton.MouseClick += (object sender, MouseEventArgs mea) =>
            {
                board.Solve(false);
                board.Draw(graphics, boardP, boardS);
            };

            Controls.Add(informationbox);
            informationbox.Multiline = true;
            informationbox.Size = new Size(160, 400);
            informationbox.BackColor = Color.LightGray;
            informationbox.Text = board.description;
        }

        private void UpdateUI()
        {
            generatebutton.Location = new Point(this.Width - 160, 30);
            hintbutton.Location = new Point(this.Width - 160, 130);
            solvebutton.Location = new Point(this.Width - 160, 230);
            informationbox.Location = new Point(40, 30);
        }
    }
}
